@@ -4,7 +4,7 @@
 #' @import data.table
 #' @importFrom survival finegray coxph Surv
 
-internal.hazard <- function(model, params) {
+internal.hazard <- function(model, params, cache) {
   event <- firstEvent <- outcomeProb <- ce <- ceProb <- trial <- NULL
   tx_bas <- paste0(params@treatment, params@indicator.baseline)
   kept <- names(params@DT)[!names(params@DT) %in% c(paste0("followup", c("", params@indicator.squared)),
@@ -12,13 +12,13 @@ internal.hazard <- function(model, params) {
                                                     "period", params@outcome)]
   
   if (!is.na(params@compevent)) {
-    ce.data <- prepare.data(params@DT, params, case = "surv", type = "compevent", model = NA)
+    ce.data <- prepare.data_cached(params@DT, params, case = "surv", type = "compevent", model = NA, cache)
     ce.model <- clean_fastglm(fastglm(ce.data$X, ce.data$y, family = quasibinomial(link = "logit"), method = params@fastglm.method))
     rm(ce.data)
   }
   
-  handler <- function(data, params, model) {
-    trials <- copy(data)[, kept, with = FALSE
+  handler <- function(data, params, model, cache) {
+    trials <- data[, kept, with = FALSE
                    ][, .SD[1], by = c(params@id, "trial")
                      ][rep(seq_len(.N), each = params@followup.max + 1)
                        ][, "followup" := seq.int(1:.N) - 1, by = c(params@id, "trial")
@@ -27,10 +27,10 @@ internal.hazard <- function(model, params) {
     out_list <- c()
     for (i in seq_along(params@treat.level)) {
       tmp <- copy(trials)[, eval(tx_bas) := params@treat.level[[i]]
-                          ][, "outcomeProb" := inline.pred(model, newdata = .SD, params, type = "outcome")
+                          ][, "outcomeProb" := inline.pred(model, newdata = .SD, params, type = "outcome", cache = cache)
                             ][, "outcome" := rbinom(.N, 1, fcoalesce(outcomeProb, 0.5))]
       if (!is.na(params@compevent)) {
-        tmp[, "ceProb" := inline.pred(ce.model, newdata = .SD, params, case = "surv")
+        tmp[, "ceProb" := inline.pred(ce.model, newdata = .SD, params, case = "surv", cache = cache)
             ][, "ce" := rbinom(.N, 1, ceProb)
               ][, "firstEvent" := if (any(outcome == 1 | ce == 1)) which(outcome == 1 | ce == 1)[1] else .N, by = c(params@id, "trial")]
       } else tmp[, "firstEvent" := if (any(outcome == 1)) which(outcome == 1)[1] else .N, by = c(params@id, "trial")]
@@ -58,31 +58,44 @@ internal.hazard <- function(model, params) {
     } else hr.res <- coxph(Surv(followup, event == 1) ~ get(tx_bas), data)
     exp(hr.res$coefficients)
   }
-  full <- handler(params@DT, params, model[[1]]$model)
+  full <- handler(params@DT, params, model[[1]]$model, cache)
   if (is.na(full)) return(c(Hazard = NA_real_, LCI = NA_real_, UCI = NA_real_))
 
   bootstrap <- if (params@bootstrap) {
     UIDs <- unique(params@DT[[params@id]])
     lnID <- length(UIDs)
-    subDT <- params@DT[, "trialID" := paste0(params@id, "_", trial)]
+    
+    # Key the data for efficient bootstrap resampling
+    if (!identical(key(params@DT), params@id)) setkeyv(params@DT, params@id)
+    
+    # Helper for efficient keyed bootstrap sampling
+    bootstrap_hazard_sample <- function(DT, params, UIDs, lnID) {
+      n_sample <- round(params@bootstrap.sample * lnID)
+      id_lookup <- data.table(
+        orig_id = sample(UIDs, n_sample, replace = TRUE),
+        boot_idx = seq_len(n_sample)
+      )
+      
+      # Single keyed join instead of N separate filters
+      RMDT <- DT[id_lookup, on = setNames("orig_id", params@id), allow.cartesian = TRUE
+                 ][, boot_idx := NULL]
+      return(RMDT)
+    }
 
     if (params@parallel) {
       setDTthreads(1)
       out <- future_lapply(1:params@bootstrap.nboot, function(x) {
-        id.sample <- sample(UIDs, round(params@bootstrap.sample * lnID), replace = TRUE)
-        RMDT <- rbindlist(lapply(seq_along(id.sample), function(x) subDT[get(params@id) == id.sample[x], ]))
-        handler(RMDT, params, model[[x]]$model)
+        RMDT <- bootstrap_hazard_sample(params@DT, params, UIDs, lnID)
+        handler(RMDT, params, model[[x]]$model, cache)
       }, future.seed = params@seed)
     } else {
       out <- lapply(1:params@bootstrap.nboot, function(x) {
         set.seed(params@seed + x)
-        id.sample <- sample(UIDs, round(params@bootstrap.sample * lnID), replace = TRUE)
-        RMDT <- rbindlist(lapply(seq_along(id.sample), function(x) subDT[get(params@id) == id.sample[x], ]))
-        handler(RMDT, params, model[[x]]$model)
+        RMDT <- bootstrap_hazard_sample(params@DT, params, UIDs, lnID)
+        handler(RMDT, params, model[[x]]$model, cache)
       })
     }
   }
-  gc()
   if (params@bootstrap) {
     bootstrap <- unlist(bootstrap)
     if (all(is.na(bootstrap))) return(c(Hazard = NA_real_, LCI = NA_real_, UCI = NA_real_))
