@@ -1,5 +1,5 @@
 test_that("Parallelism, Bootstrapping, Output Class Methods", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   model <- suppressWarnings(SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
     method = "dose-response", options = SEQopts(
       parallel = TRUE, weighted = TRUE,
@@ -11,7 +11,7 @@ test_that("Parallelism, Bootstrapping, Output Class Methods", {
 })
 
 test_that("Non-Parallel Bootstrapping", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   model <- suppressWarnings(SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
     method = "dose-response", options = SEQopts(
       parallel = FALSE, weighted = TRUE,
